%% Doing Economics with the Computer
% Harris Dellas, Lucas Kyriacou,
% University of Bern,
% Lecture 1: INTRODUCTION

%% Introduction to Matlab, A brief tutorial

% Why MATLAB?
% - MAtrix LABoratory
% - Matrix operations 
% - Useful for Economics

% Why would you want to learn to program?
% - Extremely useful for internships (!)
% - Data analysis
% - Complicated models
% - Your own projects

% => Most of the basic tools are the very similar across languages 
%   (data structures, loops, etc.)

% Why do we start with MATLAB?
% - Widely used in Ecomomics (Econometrics, Macroeconomics, Time Series)
% - Used in some classes on master level
% - Straight forward syntax
% - Very powerful tool

% Topics we will cover
% - loops, functions, applications, optimization, regression, system of equations
% - important that you also do additional exercises on your own (see Book
%   by Attaway)

% What comes after MATLAB lectures?
% - Python; why Python?
% - Powerful language, not too difficult to learn
% - Free (no licence needed)
% - Can do near infinitely many things
% - Similar to matlab in some sense (show cheatsheet)

% Motivation
% - Complex DSGE models: once you have system of equations, need
%   computational power to analyze it
% - Huge amount of data available, but how to analyze it? 
% - Create new insights by scraping websites, creating new datasets
% - Display and publish interesting results
% => all this needs some basic knowledge in coding 

% I have no prior knowledge at all, will I be lost?
% - Hopefully not, but that depends entirely on you.
% - Many additional exercises in Attaway, and online generally.
% - You can learn programming if you practice, and practice and practice. 

%% Course
% Syllabus for details
% 2 Homeworks
% Do additional exercises in Attaway! (See ilias)

%% Recommended reading after this class: 
% - Attaway, Chapter 1 - 3

%% Show Matlab
% - Create new file
% - Path
% - Create new function
% - Command window
% - Command History
% - Save your work! -> USB or Public Drive (not recommended for homework..)
% - Debugger
% - How to comment % and %%
% - The use of %% sections 
% - help function 
% - Use google :)

%% 2.1 Preliminaries
clear
close all
clc

2+3; % ; suppresses output -> you will also see that in loops

2+3

pi

format long

pi

format short

%% 2.2 Declaring variables
A = [1 2 3 
    4 5 6]

A = [1 2 3; 4 5 6]

% Careful: Zeile vor Spalte
C(1,1)=3; 
C(1,2)=4; 
C(1,3)=5; 
C(2,1)=6; 
C(2,2)=7; 
C(2,3)=8;

disp(C)

% If a variable has previously been assigned a value, the new value overrides the predecessor.
%% 2.2.2 Declaring an empty matrix
D=[]


%% 2.2.3 Building a matrix out of several submatrices
A=[1 2; 3 4];
B=[5 6 7; 8 9 10];
C=[3 4; 5 6];
D=[1 2 3; 4 5 6];

E = [A B; C D]

%% 2.2.4 Declaring a string matrix
% String: different data type!

x=['ab';'cd']
a = 1
b = '1'

% a not the same as b!

%% 2.5.5 Declaring a vector

f=[1 2 3]
g = [1; 2; 3;]

h = f'
h = [1 2 3]'

g=[1:0.5:5]

%% 2.2.6 Declaring a scalar (or 1-by-1 matrix)
a = 2;

%% 2.2.7 Managing the Matlab workspace
who

whos

% Or via workspace
% then clear
%% 2.3 Basic manipulations of matrices
% 2.3.1 Using partitions of matrices
A=[1 2 3 4 5; 
   2 3 4 5 1;  
   3 4 5 1 2; 
   4 5 1 2 3; 
   5 1 2 3 4];

B=A(1:4,2:3)

B=A(:,[1 3])

%% 2.3.2 Making vectors from matrices and reverse
Ab=[1 2; 3 4; 5 6;]

b=Ab(:) % : select all

Ab=reshape(b,3,2)

%% 2.4 Matrix and array operations
% 2.4.1 Transposition of a matrix
C=[3 4 5; 6 7 8]
C'

%% 2.4.2 Basic matrix operations
a=1:5;
b=[6:10]';
i=3;

d=a+i*a

E=b*a

% E=a*d % Does not work!

%% 2.4.3 Array operators
A = [1 2];
B = [3 3];

C=A./B % Don't confuse array operators with the usual matrix operators

%% 2.5 Relational and logical operators
% a<b  a>b  % Less (greater) than
% a<=b a>=b % Less (greater) than or equal to
% a==b      % Equal to
% a~=b      % Not equal to
% &         % AND
% |         % OR
% ~         % NOT

A = [1 2 3 4 5 6 7 8 9 10]

A=[1 2 3 4 5; 
   2 3 4 5 1;  
   3 4 5 1 2; 
   4 5 1 2 3; 
   5 1 2 3 4];

B=A(A>=5)

%%
A = [1 2 3 4 5 6 7 8 9 10]

B=A(A>=5)

%%
G= [1 2;3 4]; 

T1= G<=2

T2=~(G<=2)

t = A <= 4 & A > 2

[i,j] = find(A <= 4&A > 2);
i
j
%% 2.6 Building special matrices
% 2.6.1 Declaring a zero (or Null) matrix
D=zeros(2,3)

%% 2.6.2 Declaring a ones matrix
E=ones(2,3)

%% 2.6.3 Declaring an identity matrix
F=eye(3)

%% 2.6.4 Declaring a random matrix
R=rand(5,1)

help rand


%% 2.7.3 Sizes of each dimension of an array
[m,n]=size(A)

B=sum(A)

B=cumsum(A)

min(A)

%% 2.7.7 Determinant of a matrix
% det(A) returns the determinant of the square matrix A.
A=[4 2;1 3];
B=det(A)

%% 2.7.8 Inverse of a matrix
% inv(A) returns the inverse of the square matrix A.
C=inv(A)



